<template>
  <!-- 视频设施详情 -->
  <div class="bbsl-common-page">
    <div class="bbsl-table-search">
      <el-page-header @back="goBack" :content="this.$route.query.name">
      </el-page-header>
    </div>
    <div class="bbsl-table-content" ref="contentPanel">
      <div class="bbsl-btn-content" ref="btnPanel"></div>
      <el-tabs v-model="activeName" @tab-click="handleClick">
        <el-tab-pane label="摄像头信息" name="first">
          <div class="title-box">
            <span class="title">摄像头基础信息</span>
            <div @click="editBasic" v-if="parameters.dataType == 2">
              <i
                class="el-icon-edit bule"
                style="margin-left: 10px"
              ></i>
              <span class="bule">修改&添加</span>
            </div>
          </div>
          <div>
            <el-descriptions
              class="margin-top"
              :column="3"
              :size="size"
              border
            >
              <el-descriptions-item label="视频点名称">{{
                parameters.name
                }}
              </el-descriptions-item>
              <el-descriptions-item label="设备状态">
                                <span
                                  :style="{
                                        color:
                                            this.status == '正常'
                                                ? '#13ce66'
                                                : this.status == '异常'
                                                ? '#ff4949'
                                                : '#409EFF',
                                    }"
                                >{{ this.status }}</span
                                >
              </el-descriptions-item>
              <el-descriptions-item label="设备经度">{{
                parameters.lgtd
                }}
              </el-descriptions-item>
              <el-descriptions-item label="设备纬度">{{
                parameters.lttd
                }}
              </el-descriptions-item>
              <el-descriptions-item
                label="安装详细地址"
                span="3"
              >{{ parameters.address }}
              </el-descriptions-item
              >
            </el-descriptions>
          </div>
          <div class="title-box">
            <span class="title">摄像头扩展信息</span>
            <div @click="alterBasis">
              <i
                class="el-icon-edit bule"
                style="margin-left: 10px"
              ></i>
              <span class="bule">修改&添加</span>
            </div>
          </div>
          <div>
            <el-descriptions
              class="margin-top"
              :column="3"
              :size="size"
              border
            >
              <el-descriptions-item label="视频点编号">{{
                parameters.code
                }}
              </el-descriptions-item>
              <el-descriptions-item label="所属行政区划">{{
                this.addvcdName
                }}
              </el-descriptions-item>
              <el-descriptions-item label="所属区域">{{
                this.areaName
                }}
              </el-descriptions-item>
              <el-descriptions-item label="设备供应商">
                {{ this.supplierCompany }}
              </el-descriptions-item
              >
              <el-descriptions-item label="设备管理单位">
                {{ this.managerCompany }}
              </el-descriptions-item>
              <el-descriptions-item label="设备管理人员">
                {{ this.managerUserName }}
              </el-descriptions-item>
              <el-descriptions-item label="设备维护单位">
                {{ this.repairCompany }}
              </el-descriptions-item>
              <el-descriptions-item label="设备维护人员">
                {{ this.repairUserName }}
              </el-descriptions-item>
              <!-- <el-descriptions-item label="gis区域标识">{{
              parameters.gisArea
              }}</el-descriptions-item> -->
              <el-descriptions-item label="摄像头类型">{{
                this.videoType
                }}
              </el-descriptions-item>
              <el-descriptions-item label="安装地点类型">{{
                this.addressType
                }}
              </el-descriptions-item>
              <el-descriptions-item label="安装楼层">{{
                this.floor
                }}
              </el-descriptions-item>
              <el-descriptions-item label="使用年限">{{
                parameters.deviceVideoPointExtend.life
                }}
              </el-descriptions-item>
              <el-descriptions-item>
                <template slot="label"> 图标</template>
                <img
                  v-if="imageUrl"
                  class="icon"
                  :src="imageUrl"
                  alt=""
                  style="height: 50px; width: 50px"
                />
              </el-descriptions-item>
            </el-descriptions>
          </div>
        </el-tab-pane>
        <el-tab-pane label="状态日志" name="second">
          <VideoStatuslog
            v-if="activeName == 'second'"
            :parameter="parameters"
          ></VideoStatuslog>
        </el-tab-pane>
        <el-tab-pane label="预警信息" name="third">
          <VideoWarning
            v-if="activeName == 'third'"
            :parameter="parameters"
          ></VideoWarning>
        </el-tab-pane>
        <el-tab-pane label="所属合同" name="fourth">
          <VideoContract
            v-if="activeName == 'fourth'"
            :parameter="parameters"
          ></VideoContract>
        </el-tab-pane>
      </el-tabs>
    </div>
    <videoFormDialog @loadData="loadData" ref="videoForm"></videoFormDialog>
  </div>
</template>

<script>
import req from '@/request.js'
import {TableMixin} from '@/mixins/tableMixin'
import {ExtendParamsMixin} from '@/mixins/deviceExtend.js'
import latitude from '@/mixins/latitude'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import videoFormDialog from './videoFormDialog.vue'
import SpareCompany from '@/api/device/SpareManage.js'
import userManage from '@/api/device/userManage.js'
import resourceManage from '@/api/device/resourceManage.js'
// 组件
import VideoStatuslog from './modle/VideoStatuslog.vue'
import VideoWarning from './modle/VideoWarning.vue'
import VideoContract from './modle/VideoContract.vue'

import {error} from 'dingtalk-jsapi'

export default {
  name: 'VideoDetails',
  components: {
    VideoWarning,
    videoFormDialog,
    VideoStatuslog,
    VideoContract
  },
  mixins: [TableMixin, ExtendParamsMixin],
  data() {
    return {
      // 图标显示
      imageUrl: '',
      previewUrl:
        window.context.portal +
        '/file/onlinePreviewController/v1/getFileById_',
      activeName: 'first',
      parameters: {}, //接收参数
      size: '',
      status: '', //设备状态
      addressType: '', //安装地点类型
      floor: '', //安装楼层
      areaName: '', //所属区域
      supplierCompany: '', //设备供应商
      addvcdName: '', //所属行政区划
      managerCompany: '', //设备管理单位
      managerUserName: '', //设备管理人员
      repairCompany: '', //设备维护单位
      repairUserName: '', //设备维护人员
      videoType: '', //摄像头类型
      life: '', //使用年限
      /*
       * 字典列表
       * */
      floorList: [], //安装楼层列表
      addressTypeList: [], //安装地点类型列表
      areaOptions: [], //所属区域列表
      videoTypeList: [] //摄像头类型
    }
  },
  created() {
    this.parameters = this.$route.query
    if (this.parameters.deviceVideoPointExtend) {
      this.imageUrl =
        this.previewUrl + this.parameters.deviceVideoPointExtend.icon
    }
    this.addressTypeList = dictUtils.getDictItemsFromCache('azddlx')
    this.floorList = dictUtils.getDictItemsFromCache('azlc')
    this.videoTypeList = dictUtils.getDictItemsFromCache('sxtlx')
  },
  mounted() {
  },
  methods: {
    handleClick(tab, event) {
    },
    goBack() {
      this.$router.go(-1)
    },
    editBasic() {
      this.$refs.videoForm.editBasic(this.parameters)
    },
    alterBasis() {
      this.$refs.videoForm.OpenFormDiao(this.parameters)
    },
    formatNumber(key) {
      this.parameters[key] = latitude.TreeFour(this.parameters[key])
    },
    loadData(page) {
      // 设备状态回显
      if (this.parameters.status == '0') {
        this.status = '异常'
      } else {
        this.status = '正常'
      }
      // 摄像头类型回显
      this.videoTypeList.forEach((item) => {
        if (this.parameters.deviceVideoPointExtend) {
          if (
            this.parameters.deviceVideoPointExtend.type ==
            item.value
          ) {
            this.videoType = item.name
          }
        }
      })
      let data = {
        pageBean: {
          page: 1,
          pageSize: -1,
          showTotal: true
        }
      }
      //设备供应商
      SpareCompany.findCompanyList({}, (res) => {
        if (res && this.parameters.deviceVideoPointExtend) {
          res.forEach((item) => {
            if (
              this.parameters.deviceVideoPointExtend
                .supplierCompanyId == item.id
            ) {
              this.supplierCompany = item.companyName
            }
          })
        }
      })
      // 设备管理单位
      SpareCompany.findCompanyList({companyType: '3'}, (res) => {
        if (res && this.parameters.deviceVideoPointExtend) {
          res.forEach((item) => {
            if (
              this.parameters.deviceVideoPointExtend
                .managerCompanyId == item.id
            ) {
              this.managerCompany = item.companyName
            }
          })
        }
      })
      // 设备管理人员
      userManage
        .CompanyUser({
          companyType: '1'
        })
        .then((res) => {
          if (res) {
            res.forEach((item) => {
              if (
                item.children &&
                this.parameters.deviceVideoPointExtend
              ) {
                item.children.forEach((UserItem) => {
                  if (
                    this.parameters.deviceVideoPointExtend
                      .managerUserId == UserItem.id
                  ) {
                    this.managerUserName = UserItem.name
                  }
                })
              }
            })
          }
        })
      // 设备维护单位
      SpareCompany.findCompanyList(
        {
          companyType: '3'
        },
        (res) => {
          if (res && this.parameters.deviceVideoPointExtend) {
            res.forEach((item) => {
              if (
                this.parameters.deviceVideoPointExtend
                  .repairCompanyId == item.id
              ) {
                this.repairCompany = item.companyName
              }
            })
          }
        }
      )
      // 设备维护人员
      userManage.userQuery(data).then((res) => {
        let data = res.rows
        data.forEach((item) => {
          if (this.parameters.deviceVideoPointExtend) {
            if (
              item.id ==
              this.parameters.deviceVideoPointExtend.repairUserId
            ) {
              this.repairUserName = item.name
            }
          } else {
            this.repairUserName = ''
          }
        })
      })
      // 安装地点类型
      this.addressTypeList.forEach((item) => {
        if (this.parameters.deviceVideoPointExtend) {
          if (
            item.value ==
            this.parameters.deviceVideoPointExtend.addressType
          ) {
            this.addressType = item.name
          }
        } else {
          this.addressType = ''
        }
      })
      // 安装楼层
      this.floorList.forEach((item) => {
        if (this.parameters.deviceVideoPointExtend) {
          if (
            item.value ==
            this.parameters.deviceVideoPointExtend.floor
          ) {
            this.floor = item.name
          }
        } else {
          this.floor = ''
        }
      })
      // 所属区域
      resourceManage.loadArea(data, (res) => {
        this.areaOptions = res.rows
        this.areaOptions.forEach((item) => {
          if (this.parameters.deviceVideoPointExtend) {
            if (
              item.id ==
              this.parameters.deviceVideoPointExtend.areaId
            ) {
              this.areaName = item.name
            }
          } else {
            this.areaName = ''
          }
        })
      })
      // 所属行政区域
      resourceManage.loadAdminAreaTree({}, (res) => {
        if (this.parameters.deviceVideoPointExtend) {
          this.addvcdName = res.value[0].name
        } else {
          this.addvcdName = ''
        }
      })
    }
  }
}
</script>
<style lang="scss" scoped>
.type-tag {
  margin: 0 2px;
}

.title-box {
  display: flex;
  padding: 10px 0;

  .title {
    font-weight: 600;
  }

  .bule {
    color: #1289fd;
  }

  .bule:hover {
    cursor: pointer;
  }
}

::v-deep .el-tab-pane {
  height: calc(100% - 45px);
  overflow-y: auto;
  overflow-x: hidden;
}

::v-deep .el-descriptions-item__label.is-bordered-label {
  color: #606266;
}

// 隐藏滚动条
::v-deep .el-tab-pane::-webkit-scrollbar {
  display: none;
}

::v-deep .el-tab-pane {
  -ms-overflow-style: none;
}

::v-deep .el-tab-pane {
  overflow: -moz-scrollbars-none;
}

::v-deep .el-descriptions-item__cell {
  width: 17%;
}

.hand {
  color: #3399ff;
  cursor: pointer;
}
</style>
